@@ -1,5 +1,5 @@
 package JSON::Lines;
-use 5.006; use strict; use warnings; our $VERSION = '1.06';
+use 5.006; use strict; use warnings; our $VERSION = '1.07';
 use JSON; use base 'Import::Export';
 
 our ($JSON, $LINES, %EX);
@@ -134,7 +134,11 @@ sub _parse_headers {
 		if (ref $data[0] eq 'ARRAY') {
 			@headers = @{ shift @data };
 		} else {
-			@headers = sort keys %{ $data[0] };
+			my %key_map;
+			for (@data) {
+				%key_map = (%key_map, %{$_});
+			}
+			@headers = sort keys %key_map;
 		}
 		$self->{headers} = \@headers;
 	}
@@ -184,7 +188,7 @@ JSON::Lines - Parse JSONLines with perl.
 
 =head1 VERSION
 
-Version 1.06
+Version 1.07
 
 =cut
 
